Utilities
~~~~~~~~~

This module contains additional utilities, which may be useful for some
developers.

.. code-block:: python

    from parmoo import util

.. automodule:: util
..    :members: util

.. autofunction:: xerror

.. autofunction:: check_names

.. autofunction:: check_sims

.. autofunction:: lex_leq

.. autofunction:: updatePF

.. autofunction:: to_array

.. autofunction:: from_array
